==> worlds_timespinner-0.0.0.tar.gz: worlds_timespinner-0.0.0/src/worlds/timespinner/docs/setup_de.md <==
# Timespinner Randomizer Installationsanweisungen

## Benötigte Software

- [Timespinner (Steam)](https://store.steampowered.com/app/368620/Timespinner/)
  , [Timespinner (Humble)](https://www.humblebundle.com/store/timespinner)
  oder [Timespinner (GOG)](https://www.gog.com/game/timespinner) (andere Versionen werden nicht unterstützt)
- [Timespinner Randomizer](https://github.com/Jarno458/TsRandomizer)

## Wie funktioniert's?

Der Timespinner Randomizer lädt die Timespinner.exe im gleichen Verzeichnis und verändert seine Speicherinformationen um
die Randomisierung der Gegenstände zu erlauben

## Installationsanweisungen

1. Die aktuellsten Dateien des Randomizers findest du ganz oben auf dieser
   Webseite: [Timespinner Randomizer Releases](https://github.com/Jarno458/TsRandomizer/releases). Lade dir unter '
   Assets' die .zip Datei für dein Betriebssystem herunter
2. Entpacke die .zip Datei im Ordner, in dem das Spiel Timespinner installiert ist

## Den Randomizer starten

- auf Windows: Starte die Datei TsRandomizer.exe
- auf Linux: Starte die Datei TsRandomizer.bin.x86_64
- auf Mac: Starte die Datei TsRandomizer.bin.osx

... im Ordner in dem die Inhalte aus der .zip Datei entpackt wurden

Weitere Informationen zum Randomizer findest du hier: [ReadMe](https://github.com/Jarno458/TsRandomizer)

## An einer Multiworld teilnehmen

1. Starte den Randomizer wie unter [Den Randomizer starten](#Den-Randomizer-starten) beschrieben
2. Wähle "New Game"
3. Wechsle "<< Select Seed >>" zu "<< Archiplago >>" indem du "links" auf deinem Controller oder der Tastatur drückst
4. Wähle "<< Archipelago >>" um ein neues Menu zu öffnen, wo du deine Logininformationen für Archipelago eingeben kannst
    * ANMERKUNG: Die Eingabefelder unterstützen das Einfügen von Informationen mittels 'Ctrl + V'
5. Wähle "Connect"
6. Wenn alles funktioniert hat, wechselt das Spiel zurück zur Auswahl des Schwierigkeitsgrads und das Spiel startet,
   sobald du einen davon ausgewählt hast

## Woher bekomme ich eine Konfigurationsdatei?

Die [Player Options](https://multiworld.gg/games/Timespinner/player-options) Seite auf der Website erlaubt dir,
persönliche Einstellungen zu definieren und diese in eine Konfigurationsdatei zu exportieren

* Die Timespinner Randomizer Option "StinkyMaw" ist in Archipelago Seeds aktuell immer an
* Die Timespinner Randomizer Optionen "ProgressiveVerticalMovement" & "ProgressiveKeycards" werden in Archipelago Seeds
  aktuell nicht unterstützt

==> worlds_timespinner-0.0.1.tar.gz: worlds_timespinner-0.0.1/src/worlds/timespinner/docs/setup_de.md <==
# Timespinner Randomizer Installationsanweisungen

## Benötigte Software

- [Timespinner (Steam)](https://store.steampowered.com/app/368620/Timespinner/)
  , [Timespinner (Humble)](https://www.humblebundle.com/store/timespinner)
  oder [Timespinner (GOG)](https://www.gog.com/game/timespinner) (andere Versionen werden nicht unterstützt)
- [Timespinner Randomizer](https://github.com/Jarno458/TsRandomizer)

## Wie funktioniert's?

Der Timespinner Randomizer lädt die Timespinner.exe im gleichen Verzeichnis und verändert seine Speicherinformationen um
die Randomisierung der Gegenstände zu erlauben

## Installationsanweisungen

1. Die aktuellsten Dateien des Randomizers findest du ganz oben auf dieser
   Webseite: [Timespinner Randomizer Releases](https://github.com/Jarno458/TsRandomizer/releases). Lade dir unter '
   Assets' die .zip Datei für dein Betriebssystem herunter
2. Entpacke die .zip Datei im Ordner, in dem das Spiel Timespinner installiert ist

## Den Randomizer starten

- auf Windows: Starte die Datei TsRandomizer.exe
- auf Linux: Starte die Datei TsRandomizer.bin.x86_64
- auf Mac: Starte die Datei TsRandomizer.bin.osx

... im Ordner in dem die Inhalte aus der .zip Datei entpackt wurden

Weitere Informationen zum Randomizer findest du hier: [ReadMe](https://github.com/Jarno458/TsRandomizer)

## An einer Multiworld teilnehmen

1. Starte den Randomizer wie unter [Den Randomizer starten](#Den-Randomizer-starten) beschrieben
2. Wähle "New Game"
3. Wechsle "<< Select Seed >>" zu "<< Archiplago >>" indem du "links" auf deinem Controller oder der Tastatur drückst
4. Wähle "<< Archipelago >>" um ein neues Menu zu öffnen, wo du deine Logininformationen für Archipelago eingeben kannst
    * ANMERKUNG: Die Eingabefelder unterstützen das Einfügen von Informationen mittels 'Ctrl + V'
5. Wähle "Connect"
6. Wenn alles funktioniert hat, wechselt das Spiel zurück zur Auswahl des Schwierigkeitsgrads und das Spiel startet,
   sobald du einen davon ausgewählt hast

## Woher bekomme ich eine Konfigurationsdatei?

Die [Player Options](/games/Timespinner/player-options) Seite auf der Website erlaubt dir,
persönliche Einstellungen zu definieren und diese in eine Konfigurationsdatei zu exportieren

* Die Timespinner Randomizer Option "StinkyMaw" ist in Archipelago Seeds aktuell immer an
* Die Timespinner Randomizer Optionen "ProgressiveVerticalMovement" & "ProgressiveKeycards" werden in Archipelago Seeds
  aktuell nicht unterstützt
